@@ -4,10 +4,10 @@
 extern crate pathfinding;
 
 use pathfinding::prelude::*;
-use std::io::{self, Cursor};
-use std::io::prelude::*;
-use std::num::ParseIntError;
 use std::collections::{BTreeMap, BTreeSet, HashMap, HashSet};
+use std::io::prelude::*;
+use std::io::{self, Cursor};
+use std::num::ParseIntError;
 
 #[derive(Debug)]
 enum Error {
@@ -123,8 +123,7 @@ fn test<EK: EdmondsKarp<i32>>(n: usize, file: &mut BufRead) -> Result<String, Er
                 }
             }
             max
-        })
-        .max()
+        }).max()
         .unwrap();
     Ok(format!("Case #{}: {}", n, answer))
 }
